@@ -1,7 +1,10 @@
 from ._thanker import Thanker
+from ._group_by import GroupBy
+
+from .web import webpanel, APP
 
 
-__version__ = "0.0.4"
+__version__ = "0.0.6"
 __url__ = "https://github.com/WardPearce/thanker"
 __description__ = "Don't be a wanker, be a thanker!"
 __author__ = "WardPearce"
@@ -10,5 +13,8 @@ __license__ = " Apache-2.0"
 
 
 __all__ = [
-    "Thanker"
+    "Thanker",
+    "GroupBy",
+    "webpanel",
+    "APP"
 ]
